@@ -3,17 +3,22 @@ import sys
 from dataclasses import dataclass
 from pathlib import Path
 from textwrap import wrap
-from typing import Optional
-
+from typing import TYPE_CHECKING, Optional
+import re
 
 import requests
-import yaml
+from arc import Context
 from arc.color import effects, fg
 from arc.errors import ExecutionError
-from arc.utils import logger
 
+from .cache import Cache
+from .harvest_api import HarvestApi
+from .sync import Sync
 from .ui import menu
 
+if TYPE_CHECKING:
+    from .helpers import Project
+
 
 @dataclass
 class Config:
@@ -39,52 +44,12 @@ class Config:
         return Config(**data)
 
 
-class Cache:
-    NOT_LOADED = ExecutionError("Cache not yet loaded")
-
-    def __init__(self, file: Path):
-        self.cache_file = file
-        self._data: dict = {}
-        self.loaded = False
-
-    # Dictionary Pass through functions
-    def __getitem__(self, item):
-        self.load()
-        return self._data.get(item)
-
-    def __setitem__(self, key, value):
-        self.load()
-        self._data[key] = value
-
-    def __delitem__(self, key):
-        self.load()
-        del self._data[key]
-
-    def pop(self, value):
-        if isinstance(self._data, dict):
-            return self._data.pop(value)
-
-        raise Cache.NOT_LOADED
-
-    def save(self):
-        logger.debug("%sWriting cache...%s", fg.YELLOW, effects.CLEAR)
-        with open(self.cache_file, "w") as file:
-            file.write(yaml.dump(self._data))
-
-    def load(self):
-        if not self.loaded:
-            logger.debug("%sLoading Cache%s", fg.YELLOW, effects.CLEAR)
-            self._data = self.__load()
-            self.loaded = True
-
-    def __load(self):
-        try:
-            file = open(self.cache_file, "r")
-            data: dict = yaml.load(file, yaml.Loader)
-            file.close()
-        except FileNotFoundError:
-            data = {}
-        return data
+class ScytheContext(Context):
+    api: HarvestApi
+    config: Config
+    cache: Cache
+    projects: Optional[list["Project"]]
+    syncer: Sync
 
 
 def handle_response(res: requests.Response):
@@ -131,5 +96,15 @@ def parse_time(time: float):
 
 
 def format_time(hours, minutes):
-    minutes_str = str(minutes) if minutes > 10 else f"0{minutes}"
+    minutes_str = str(minutes) if minutes >= 10 else f"0{minutes}"
     return f"{hours}:{minutes_str}"
+
+
+def set_title(title: str):
+    sys.stdout.write(f"\x1b]2;{title}\x07")
+
+
+def clean(string):
+    """Gets rid of escape sequences"""
+    ansi_escape = re.compile(r"(\x9B|\x1B\[)[0-?]*[ -\/]*[@-~]")
+    return ansi_escape.sub("", str(string))
